@@ -494,9 +494,9 @@ class DataTransformerForm(BaseInlineFormSet):
                                                                  fk_name='parent', form=DataTransform, extra=1
                                                                  )
             form.nested_data_transformer_form = dataTransformerInlineFormset(
+                instance=form.instance,
                 data=form.data if form.is_bound else None,
-                files=form.files if form.is_bound else None,
-                initial = [{'parent': form.instance}]
+                files=form.files if form.is_bound else None
             )
 
 
